@@ -9,16 +9,16 @@ import (
 // counterparts we will always return a non-zero exit number so sensitive scripts can fail gracefully.
 
 func init() {
-	lang.GoFunctions["ps"] = alias("tasklist")
-	lang.GoFunctions["ls"] = alias("dir")
-	lang.GoFunctions["rm"] = alias("del")
-	lang.GoFunctions["clear"] = alias("cls")
-	lang.GoFunctions["cat"] = alias("type")
+	lang.DefineFunction("ps", alias("tasklist"), types.Generic)
+	lang.DefineFunction("ls", alias("dir"), types.Generic)
+	lang.DefineFunction("rm", alias("del"), types.Null)
+	lang.DefineFunction("clear", alias("cls"), types.Null)
+	lang.DefineFunction("cat", alias("types"), types.Generic)
 }
 
 func alias(cmd string) func(p *lang.Process) error {
 	return func(p *lang.Process) error {
-		p.Stdout.SetDataType(types.String)
+		p.Stdout.SetDataType(types.Generic)
 
 		p.Name.Set("exec")
 
