@@ -4,24 +4,28 @@ set -ev
 
 . /etc/ci-murex.env
 
-#[ -z "$MUREX_BUILD_WEBSITE_ONLY" ] && \
-#        export MUREX_BUILD_WEBSITE_ONLY="$(git describe --tags --match website)"
-
-#export MUREX_BUILD="$(git log -1 --pretty=%B | egrep '^website: ')"
-
 mkdir -p /website
 
+#export MUREXVERSION="$(murex -c 'version --no-app-name')"
+export MUREXVERSION="$(cat app/app.go | grep 'const Version' | egrep -o '[0-9]+\.[0-9]+\.[0-9]+')"
+OLDVER="$(curl -s https://murex.rocks/VERSION | head -n1)"
 
-echo "Building latest binaries...."
-#if [ "$MUREX_BUILD" != "website: " ]; then
+if [ "$MUREXVERSION" == "$OLDVER" ]; then
+        echo "No version change, skipping binary build."
+else
+        echo "Building latest binaries...."
         murex ./test/build_all_platforms.mx $MUREX_BUILD_FLAGS
         mv -v ./bin /website/
-#else
-#        echo "!!! Commit appears to only update website, skipping compile tests !!!"
-#fi
+
+        echo "Compiling WebAssembly...."
+        export GOOS=js
+        export GOARCH=wasm
+        go build -o ./gen/website/wasm/murex.wasm
+        cp -v "$(go env GOROOT)/misc/wasm/wasm_exec.js" ./gen/website/wasm/
+fi
 
 echo "Building website...."
-export MUREXVERSION="$(murex -c 'version --no-app-name')"
+
 export MUREXCOMMITS="$(git rev-parse HEAD | cut -c1-7)"
 export MUREXCOMMITL="$(git rev-parse HEAD)"
 export MUREXTESTS="$(cat ./test/murex-test-count.txt)"
@@ -58,15 +62,11 @@ sed -i '0,/<img src/s//<img class="no-border" src/;
         0,/<img src/s//<img class="no-border" src/;' \
         INSTALL.html
 
-echo "Compiling WebAssembly...."
+sed -i '0,/<img src/s//<img class="no-border" src/;' \
+        DOWNLOAD.html
 
-export GOOS=js
-export GOARCH=wasm
-go build -o ./gen/website/wasm/murex.wasm
-cp -v "$(go env GOROOT)/misc/wasm/wasm_exec.js" ./gen/website/wasm/
+echo "$MUREXVERSION" > VERSION
 
-
-
-mv *.html gen/website/assets/* ./docs /website/
+mv VERSION *.html *.svg gen/website/assets/* ./docs /website/ 
 
 echo "Fin!"
\ No newline at end of file
